polytopes_db_4d: Database of 4-dimensional reflexive polytopes
==============================================================

Description
-----------

This package contains the database of 4-d reflexive polytopes with Hodge
numbers as index.

Based on the original list by Maximilian Kreuzer and Harald Skarke using
their software PALP.

License
-------

GPL v2+

SPKG Maintainers
----------------

Volker Braun <vbraun.name@gmail.com>

